from trytond.pool import Pool
from trytond.model import ModelSQL, ModelView, ModelSingleton, fields
from trytond.modules.company.model import (
    CompanyMultiValueMixin, CompanyValueMixin)


class Configuration(
        ModelSingleton, ModelSQL, ModelView, CompanyMultiValueMixin):
    'Facho Configuration'
    __name__ = 'account_invoice_facho.configuration'

    dian_fe_habilitation = fields.MultiValue(fields.Boolean('Habilitation'))
    dian_fe_debit_note = fields.MultiValue(fields.Boolean('Debit Note'))
    dian_fe_public_key = fields.MultiValue(fields.Binary('Public Key',
                                                         help="PCKS#12"))
    dian_fe_private_key = fields.MultiValue(fields.Binary('Private Key',
                                                          help="PCKS#12"))
    dian_fe_cert = fields.MultiValue(fields.Binary('Cert',
                                                   help="PCKS#12"))
    dian_fe_cert_passpharase = fields.MultiValue(fields.Char('Cert Passpharase'))
    dian_fe_test_setid = fields.MultiValue(fields.Char('Testsetid Dian'))
    dian_fe_technologic_supplier  = fields.MultiValue(fields.Many2One('party.party',
                                                                        'Technologic Supplier'))
    dian_fe_obliged_bill = fields.MultiValue(fields.Many2One('party.party',
                                                                            'Obliged to bill'))
    dian_fe_software_identification = fields.MultiValue(fields.Char('Software Identification'))
    dian_fe_pin = fields.MultiValue(fields.Char('PIN'))
    dian_fe_invoice_resolution = fields.MultiValue(fields.Many2One('account.invoice.resolution',
                                                                       'Invoice Resolution'))
    
    @classmethod
    def multivalue_model(cls, field):
        pool = Pool()
        return pool.get('account_invoice_facho.dian_fe_company')

 
class ConfigurationDianFECompany(ModelSQL, CompanyValueMixin):
    'Configuration - DianFECompany'
    __name__ = 'account_invoice_facho.dian_fe_company'

    configuration = fields.Many2One('account_invoice_facho.configuration', 'Configuration',
        required=True, ondelete='CASCADE')
    dian_fe_habilitation = fields.Boolean('Habilitation')
    dian_fe_debit_note = fields.Boolean('Debit Note')
    dian_fe_public_key = fields.Binary('Public Key',
                                       help="PCKS#12")
    dian_fe_private_key = fields.Binary('Private Key',
                                        help="PCKS#12")
    dian_fe_test_setid = fields.Char('Testsetid Dian')
    dian_fe_cert = fields.Binary('Cert',
                                 help="PCKS#12")
    dian_fe_cert_passpharase = fields.Char('Cert Passpharase')
    dian_fe_technologic_supplier = fields.Many2One('party.party',
                                                      'Technologic Supplier')
    dian_fe_obliged_bill = fields.Many2One(
        'party.party',
        'Obliged to bill')
    dian_fe_software_identification = fields.Char('Software Identification')
    dian_fe_pin = fields.Char('PIN')
    dian_fe_invoice_resolution = fields.Many2One('account.invoice.resolution',
                                                     'Invoice Resolution')
